# Section 2 {#sec:2}

## Subsection 2

### Subsubsection 2

before

```python {title=abc numbers=left}
AAA=1
```

```python {.output}
AAA=1
BBB=1
```

```python {.output baselinestretch=1.05}
AAA=1
BBB=1
```

```python {.output}
AAA=1
BBB=1
```

after

![pdf](pdf.ipynb){#fig:pdf}

![raster](raster.ipynb){#fig:raster}

![seaborn](seaborn.ipynb){#fig:seaborn}

![holoviews](holoviews.ipynb){#fig:holoviews}

![hvplot](hvplot.ipynb){#fig:hvplot}

![figure](figure.pdf){#fig:figure}